Tutorials
=========

.. toctree::
   :maxdepth: 1
   :caption: Tutorials

   categorical_data
   toy_datasets
   benchmark
   custom_objective.ipynb
   causal/uplift_marketing.ipynb
   causal/iv_causal_effect.ipynb
   causal/risk_compliance.ipynb
   causal/heterogeneous_treatment_effects.ipynb
   causal/fairness_aware_modeling.ipynb
   causal/customer_retention_uplift.ipynb
